# TokenValidity

Token validity
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**start** | **datetime** | The start time for when the token is valid | [optional] 
**duration** | **int** | The duration of time for which the token is valid | [optional] 
**end** | **datetime** | The end time for when the token is valid | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


